using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using UnityEngine;
using UnityEngine.Events;

namespace RightClick
{
    public class RightClickPersonBehaviour : MonoBehaviour
    {
        public SyringeBehaviour lifeS = new LifeSyringe();
        public SyringeBehaviour zombieS = new ZombieSyringe();

        public bool NoPain = false;
        public bool Invincibling = false;
        public bool NoDrown = false;
        public bool NoBurning = false;
        public bool Suffocating = false;
        public bool collapsed = false;
        public bool zombified = false;

        public PersonBehaviour PB;
        public Vector2 limits = new LifeSyringe().Limits;

        void Start()
        {
            PB = gameObject.GetComponent<PersonBehaviour>();
            
            foreach (var limb in PB.Limbs) {
                if (!limb.gameObject.GetComponent<RightClickLimbBehaviour>()) {
                    limb.gameObject.AddComponent<RightClickLimbBehaviour>();
                }
            }
        }

        void Update()
        {
            if (NoPain) {
                PB.PainLevel = 0.0f;
                PB.ShockLevel = 0.0f;
            }

            if (NoDrown) {
                PB.OxygenLevel = 1f;
            }

            if (Suffocating) {
                PB.OxygenLevel = 0f;
                PB.PainLevel = 1f;
            }

            if (NoBurning) {
                foreach (var limb in PB.Limbs) {
                    CirculationBehaviour circulationBehaviour = limb.CirculationBehaviour;
                    circulationBehaviour.ClearLiquid();
                    circulationBehaviour.AddLiquid(limb.GetOriginalBloodType(), 1f);
                    circulationBehaviour.BloodFlow = 1f;
                    
                    limb.PhysicalBehaviour.Extinguish();
                    limb.PhysicalBehaviour.BurnProgress *= 0f;        
                    limb.InternalTemperature = limb.BodyTemperature;
                    limb.GetComponent<PhysicalBehaviour>().BurnProgress = 0f;
                    limb.GetComponent<SkinMaterialHandler>().RottenProgress = 0f;
                }
            }

/*
            checkNextUpdate += Time.deltaTime;
            if (checkNextUpdate < 0.5f) {
                return; 
            }
            checkNextUpdate = 0.0f;
*/
            if (Invincibling) {
                foreach (var limb in PB.Limbs)
                {
                    if (limb.IsAndroid) {
                        CirculationBehaviour circulationBehaviour = limb.CirculationBehaviour;
                        limb.Health = limb.InitialHealth;
                        limb.HealBone();
                        circulationBehaviour.HealBleeding();
                        circulationBehaviour.ClearLiquid();
                        circulationBehaviour.AddLiquid(limb.GetOriginalBloodType(), 1f);
                        circulationBehaviour.BloodFlow = 1f;
                        circulationBehaviour.IsPump = circulationBehaviour.WasInitiallyPumping;
                        limb.Person.Consciousness = 1f;
                        limb.PhysicalBehaviour.BurnProgress *= 0f;        
                        continue;
                    }

                    if (limb.HasBrain) {
                        Liquid.GetLiquid(lifeS.GetLiquidID()).Color = limb.GetOriginalBloodType().Color;
                        limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid(lifeS.GetLiquidID()), limits.y);
                    }
                }
            }
        }
    }
}